@@ -128,7 +128,7 @@ class SolanaWallet:
 class APIResource:
 
     _url = "https://api.blockchainapi.com/v1/"
-    __timeout = 120
+    __timeout = 300
 
     class _RequestMethod(Enum):
         GET = "GET"
@@ -153,7 +153,7 @@ class APIResource:
                 raise Exception("`timeout` must be an integer")
             if timeout < 1:
                 raise Exception("`timeout` must be at least 1 second.")
-            if timeout > 120:
+            if timeout > 300:
                 raise Exception("`timeout` must be at most 120 second.")
             self.__timeout = timeout
 
@@ -168,7 +168,15 @@ class APIResource:
             'Language': 'Python'
         }
 
-    def _request(self, endpoint, request_method, files=None, headers=None, payload=None, params=None):
+    def _request(
+        self,
+        endpoint,
+        request_method,
+        files=None,
+        headers=None,
+        payload=None,
+        params=None
+    ):
         """
         Makes an API request.
         :param payload: the payload containing the parameters
@@ -413,7 +421,7 @@ class SolanaAPIResource(APIResource):
         self,
         mint_address: str,
         network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
+    ) -> str:
         response = self._request(
             endpoint=f"solana/nft/{network.value}/{mint_address}/owner",
             request_method=self._RequestMethod.GET
@@ -422,6 +430,25 @@ class SolanaAPIResource(APIResource):
             raise Exception(response['error_message'])
         return response['nft_owner']
 
+    def get_nft_owner_advanced(
+        self,
+        mint_address: str,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ) -> dict:
+        """
+        https://docs.blockchainapi.com/#tag/Solana-NFT/operation/solanaGetNFTOwnerAdvanced
+        :param mint_address:
+        :param network:
+        :return:
+        """
+        response = self._request(
+            endpoint=f"solana/nft/{network.value}/{mint_address}/owner_advanced",
+            request_method=self._RequestMethod.GET
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
     def get_associated_token_account_address(
         self,
         mint_address: str,
@@ -454,6 +481,7 @@ class SolanaAPIResource(APIResource):
         recipient_address: str,
         token_address: Optional[str] = None,
         network: SolanaNetwork = SolanaNetwork.DEVNET,
+        wait_for_confirmation: Optional[bool] = None,
         amount: str = "1",
         fee_payer_wallet: Optional[SolanaWallet] = None,
         sender_public_key: Optional[str] = None,
@@ -466,6 +494,7 @@ class SolanaAPIResource(APIResource):
         :param recipient_address: The recipient of the transfer
         :param token_address: If not provided, defaults to transferring SOL
         :param network: The network, e.g. mainnet-beta or devnet
+        :param wait_for_confirmation: Whether to wait for the tx to be confirmed. See docs for more info.
         :param amount: The amount to transfer
         :param fee_payer_wallet: OPTIONAL: The fee payer of the transaction.
         The default is the wallet from which the transfer is occurring
@@ -496,6 +525,9 @@ class SolanaAPIResource(APIResource):
         if fee_payer_wallet is not None:
             payload["fee_payer_wallet"] = fee_payer_wallet.get_formatted_request_payload()['wallet']
 
+        if wait_for_confirmation is not None:
+            payload['wait_for_confirmation'] = wait_for_confirmation
+
         response = self._request(
             payload=payload,
             endpoint="solana/wallet/transfer",
@@ -513,6 +545,7 @@ class SolanaAPIResource(APIResource):
         name: Optional[str] = None,
         symbol: Optional[str] = None,
         description: Optional[str] = None,
+        wait_for_confirmation: Optional[bool] = None,
         uri: Optional[str] = None,
         image_url: Optional[str] = None,
         uri_metadata: Optional[dict] = None,
@@ -532,6 +565,7 @@ class SolanaAPIResource(APIResource):
         :param name: The name of the NFT
         :param symbol: The symbol of the NFT
         :param description: The description of the NFT
+        :param wait_for_confirmation: Whether to wait for the tx to be confirmed. See docs for more info.
         :param uri: The image of the NFT. Please see the description in the documentation
          (docs.blockchainapi.com/#operation/solanaCreateNFT)
         :param image_url: Please see the description in the documentation.
@@ -569,6 +603,8 @@ class SolanaAPIResource(APIResource):
             payload['share'] = share
         if mint_to_public_key is not None:
             payload['mint_to_public_key'] = mint_to_public_key
+        if wait_for_confirmation is not None:
+            payload['wait_for_confirmation'] = wait_for_confirmation
 
         response = self._request(
             payload=payload,
@@ -718,40 +754,6 @@ class SolanaAPIResource(APIResource):
             raise Exception(response['error_message'])
         return response
 
-    def mint_from_candy_machine(
-        self,
-        config_address: str,
-        wallet: SolanaWallet,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        Mint Info:
-        https://docs.blockchainapi.com/#operation/solanaMintFromCandyMachine
-        :param config_address: The config address of the candy machine.
-        You can retrieve this if you have the candy machine ID using
-        this endpoint (https://docs.blockchainapi.com/#operation/solanaGetCandyMachineDetails)
-        and retrieving the config_address from the response..
-        :param wallet:
-        :param network:
-        :return: A task_id. Use the `get_task` function to retrieve the result once this task has completed processing.
-        You can poll the `get_task` function to see results.
-        """
-        wallet_payload = wallet.get_formatted_request_payload()
-        payload = {
-            "network": network.value,
-            "config_address": config_address,
-            "candy_machine_contract_version": "v2"
-        }
-        payload = {**payload, **wallet_payload}
-        response = self._request(
-            payload=payload,
-            endpoint="solana/nft/candy_machine/mint",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['transaction_signature']
-
     def list_all_candy_machines(self):
         """
 
@@ -809,35 +811,6 @@ class SolanaAPIResource(APIResource):
             raise Exception(response['error_message'])
         return response
 
-    def create_test_candy_machine(
-        self,
-        wallet: SolanaWallet,
-        include_gatekeeper: bool = False,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        Mint Info:
-        https://docs.blockchainapi.com/#operation/solanaCreateTestCandyMachine
-        :param wallet:
-        :param network:
-        :param include_gatekeeper:
-        :return:
-        """
-        wallet_payload = wallet.get_formatted_request_payload()
-        payload = {
-            "network": network.value,
-            "include_gatekeeper": include_gatekeeper
-        }
-        payload = {**payload, **wallet_payload}
-        response = self._request(
-            payload=payload,
-            endpoint="solana/nft/candy_machine",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['candy_machine_id']
-
     def get_solana_transaction(
         self,
         tx_signature: str,
@@ -942,130 +915,3 @@ class SolanaAPIResource(APIResource):
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response
-
-    def get_nft_listing(
-        self,
-        mint_address: str,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        https://docs.blockchainapi.com/#operation/solanaGetAccount
-        """
-        response = self._request(
-            endpoint=f"solana/nft/marketplaces/listing/{network.value}/{mint_address}",
-            request_method=self._RequestMethod.GET
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response
-
-    def list_nft(
-        self,
-        mint_address: str,
-        wallet: SolanaWallet,
-        nft_price: int,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        https://docs.blockchainapi.com/#operation/solanaGetAccount
-        """
-        payload = wallet.get_formatted_request_payload()
-        payload['nft_price'] = nft_price
-        response = self._request(
-            payload=payload,
-            endpoint=f"solana/nft/marketplaces/magic-eden/list/{network.value}/{mint_address}",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['transaction_signature']
-
-    def delist_nft(
-        self,
-        mint_address: str,
-        wallet: SolanaWallet,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        https://docs.blockchainapi.com/#operation/solanaGetAccount
-        """
-        payload = wallet.get_formatted_request_payload()
-        response = self._request(
-            payload=payload,
-            endpoint=f"solana/nft/marketplaces/magic-eden/delist/{network.value}/{mint_address}",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['transaction_signature']
-
-    def buy_nft(
-        self,
-        mint_address: str,
-        wallet: SolanaWallet,
-        nft_price: int,
-        network: SolanaNetwork = SolanaNetwork.DEVNET,
-        skip_checks: Optional[bool] = None,
-        seller_public_key: Optional[str] = None
-    ):
-        """
-        https://docs.blockchainapi.com/#operation/solanaGetAccount
-        """
-        payload = wallet.get_formatted_request_payload()
-        payload['nft_price'] = nft_price
-        if skip_checks is not None:
-            payload['skip_checks'] = skip_checks
-        if seller_public_key is not None:
-            payload['seller_public_key'] = seller_public_key
-        response = self._request(
-            payload=payload,
-            endpoint=f"solana/nft/marketplaces/magic-eden/buy/{network.value}/{mint_address}",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['transaction_signature']
-
-    def get_nft_marketplace_analytics(
-        self,
-        mint_addresses: List[str],
-        start_time: Optional[int] = None,
-        end_time: Optional[int] = None
-    ):
-        if not isinstance(mint_addresses, list):
-            raise Exception("`mint_addresses` must be a list of mint addresses.")
-        payload = {
-            'mint_addresses': mint_addresses
-        }
-        if start_time is not None:
-            payload['start_time'] = start_time
-        if end_time is not None:
-            payload['end_time'] = end_time
-        response = self._request(
-            payload=payload,
-            endpoint=f"solana/nft/marketplaces/analytics",
-            request_method=self._RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response
-
-    def get_recent_nft_transactions(self):
-        response = self._request(
-            payload=dict(),
-            endpoint=f"solana/nft/marketplaces/analytics/recent_transactions",
-            request_method=self._RequestMethod.GET
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response
-
-    def get_nft_market_share(self):
-        response = self._request(
-            payload=dict(),
-            endpoint=f"solana/nft/marketplaces/analytics/market_share",
-            request_method=self._RequestMethod.GET
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response
